#include <stdio.h>
#include <string.h>

template<unsigned long TLength>
class longnum
{
	long digits[TLength];
	long length;

	void normalize(void)
	{
		long iDigit;
		if(length >= TLength)fputs("Overflow", stderr);
		for(iDigit = 0; iDigit < length; ++iDigit)
			if(digits[iDigit] > 65535)
			{
				digits[iDigit + 1] += (digits[iDigit] >> 16);
				digits[iDigit] &= 65535;
			}
		while(length && !digits[length - 1])--length;
	}

	longnum(const longnum &num1, short num2, char op)
	{
		if(op == '*')
		{
			*this = num1;
			*this *= num2;
		}
	}

	longnum(const longnum &num1, const longnum &num2, char op)
	{
		if(op == '+')
		{
			*this = num1;
			*this += num2;
		}
	}

public:
	longnum(void)
	{
		length = 0;
	}

	longnum(const longnum& num)
	{
		length = num.length;
		memcpy(digits, num.digits, sizeof(digits[0]) * length);
	}
	longnum(short num)
	{
		if(!num)length = 0;
		else
		{
			length = 1;
			digits[0] = num;
		}
	}
	
	const longnum& operator=(const longnum &num)
	{
		length = num.length;
		memcpy(digits, num.digits, sizeof(digits[0]) * length);
		return *this;
	}

	const longnum& operator+=(const longnum& num)
	{
		long iDigit;
		if(length < num.length)
		{
			for(iDigit = 0; iDigit < length; ++iDigit)
				digits[iDigit] += num.digits[iDigit];
			for(; iDigit < num.length; ++iDigit)
				digits[iDigit] = num.digits[iDigit];
			digits[num.length] = 0;
			length = num.length + 1;
			normalize();
		}
		else
		{
			for(iDigit = 0; iDigit < num.length; ++iDigit)
				digits[iDigit] += num.digits[iDigit];
			digits[length] = 0;
			++length;
			normalize();
		}
		return *this;
	}

	const longnum& operator*=(short num)
	{
		long iDigit;
		for(iDigit = 0; iDigit < length; ++iDigit)
			digits[iDigit] *= num;
		digits[length] = 0;
		++length;
		normalize();
		return *this;
	}

	longnum operator*(short num)
	{
		return longnum(*this, num, '*');
	}

	longnum operator+(const longnum &num)
	{
		return longnum(*this, num, '+');
	}

	void print(void)
	{
		if(! length)
		{
			putchar('0');
			return;
		}
		long outputDigits[TLength], outputLength = length, rem, iDigit;
		char output[TLength * 6];
		long outputChars = 0;
		memcpy(outputDigits, digits, sizeof(digits[0]) * length);
		while(outputLength)
		{
			rem = 0;
			for(iDigit = outputLength - 1; iDigit >= 0; --iDigit)
			{
				outputDigits[iDigit] += (rem << 16);
				rem = outputDigits[iDigit] % 10;
				outputDigits[iDigit] /= 10;
			}
			output[outputChars++] = char(rem + '0');
			while(outputLength && !outputDigits[outputLength - 1])--outputLength;
		}
		while(outputChars--)putchar(output[outputChars]);
	}
};

typedef longnum<1000> mylongnum;

int main()
{
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);

	short K;
	scanf("%hd", &K);
	
	mylongnum bad(0), good1(1), good6(1), good66(0), good(7);
	mylongnum new_good1(0), new_good6(0), new_good66(0);
	for(short iK = 1; iK < K; ++iK)
	{
		bad = bad*10 + good1 + good66;
		
		new_good1 = good1 + good6 + good66 + good;
		new_good6 = good1 + good;
		new_good66 = good6;
		
		good = good1*7 + good6*8 + good66*8 + good*8;
		good1 = new_good1;
		good6 = new_good6;
		good66 = new_good66;
	}
	bad.print();
	putchar('\n');

	fclose(stdin);
	fclose(stdout);
	return 0;
}
